Address

Struct Address 

pub struct Address(/* private fields */);
SuiAddress scalar in Sui GraphQL schema. 32-byte hex-encoded address with 0x prefix. Unique identifier for an Account on the Sui blockchain.

An Address is a 32-byte pseudonymous identifier used to uniquely identify an account and asset-ownership on the Sui blockchain. Often, human-readable addresses are encoded in hexadecimal with a 0x prefix. For example, this is a valid Sui address: 0x02a212de6a9dfa3a69e22387acfbafbb1a9e591bd9d636e7895dcfc8de05f331.

use sui_sdk_types::Address;

let hex = "0x02a212de6a9dfa3a69e22387acfbafbb1a9e591bd9d636e7895dcfc8de05f331";
let address = Address::from_hex(hex).unwrap();
println!("Address: {}", address);
assert_eq!(hex, address.to_string());

Deriving an account Address

Account addresses are cryptographically derived from a number of user account authenticators, the simplest of which is an Ed25519PublicKey.

Deriving an address consists of the Blake2b256 hash of the sequence of bytes of its corresponding authenticator, prefixed with a domain-separator. For each authenticator, this domain-separator is the single byte-value of its SignatureScheme flag. E.g. hash(signature schema flag || authenticator bytes).

Each authenticator includes a convince method for deriving its Address as well as documentation for the specifics of how the derivation is done. See Ed25519PublicKey::derive_address for an example.

Usage as ObjectIds

Addresses are also used as a way to uniquely identify an Object. When an Address is used as an object identifierit can also be referred to as an ObjectId. ObjectIds and account Addresses share the same 32-byte addressable space but are derived leveraging different domain-separator values to ensure, cryptographically, that there won’t be any overlap, e.g. there can’t be a valid Object whose ObjectId is equal to that of the Address of a user account.

BCS

An Address’s BCS serialized form is defined by the following:

address = 32OCTET

Implementations



impl Address

pub const LENGTH: usize = 32

pub const ZERO: Address

pub const TWO: Address

pub const THREE: Address

pub const fn new(bytes: [u8; 32]) -> Address

pub fn generate<R>(rng: R) -> Address
where R: RngCore + CryptoRng,

pub const fn into_inner(self) -> [u8; 32]

Return the underlying byte array of a Address.

pub const fn inner(&self) -> &[u8; 32]

pub const fn as_bytes(&self) -> &[u8]

pub fn from_hex<T>(hex: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,

Decodes an address from a hex encoded string.

pub const fn from_static(hex: &'static str) -> Address

Decodes an address from a hex encoded &’static str.

Similar to from_hex except any errors are unwrapped, turning them into panics.

pub fn to_hex(&self) -> String

pub fn from_bytes<T>(bytes: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,



impl Address

pub fn derive_id(digest: Digest, count: u64) -> Address

Create an ObjectId from TransactionDigest and count.

count is the number of objects that have been created during a transactions.

pub fn derive_dynamic_child_id( &self, key_type_tag: &TypeTag, key_bytes: &[u8], ) -> Address

Derive an ObjectId for a Dynamic Child Object.

hash(parent || len(key) || key || key_type_tag)

pub fn derive_object_id( &self, key_type_tag: &TypeTag, key_bytes: &[u8], ) -> Address

Derive the address of a derived_object

hash(parent || len(key) || key || DerivedObjectKey(key_type_tag))