Digest

Struct Digest 

pub struct Digest(/* private fields */);
Useful for digest fields (Base58 string). Not a scalar in Sui GraphQL schema. A 32-byte Blake2b256 hash output.

BCS

A Digest’s BCS serialized form is defined by the following:

digest = %x20 32OCTET

Due to historical reasons, even though a Digest has a fixed-length of 32, Sui’s binary representation of a Digest is prefixed with its length meaning its serialized binary form (in bcs) is 33 bytes long vs a more compact 32 bytes.

Implementations



impl Digest

pub const LENGTH: usize = 32

A constant representing the length of a digest in bytes.

pub const ZERO: Digest

A constant representing a zero digest.

pub const fn new(digest: [u8; 32]) -> Digest

Generates a new digest from the provided 32 byte array containing u8 values.

pub fn generate<R>(rng: R) -> Digest
where R: RngCore + CryptoRng,

Generates a new digest from the provided random number generator.

pub const fn inner(&self) -> &[u8; 32]

Returns a slice to the inner array representation of this digest.

pub const fn into_inner(self) -> [u8; 32]

Returns the inner array representation of this digest.

pub const fn as_bytes(&self) -> &[u8]

Returns a slice of bytes representing the digest.

pub fn from_base58<T>(base58: T) -> Result<Digest, DigestParseError>
where T: AsRef<[u8]>,

Decodes a digest from a Base58 encoded string.

pub const fn from_static(base58: &'static str) -> Digest

Decodes a digest from a Base58 encoded &’static str.

Similar to from_base58 except any errors are unwrapped, turning them into panics.

pub fn to_base58(&self) -> String

Returns a Base58 encoded string representation of this digest.

pub fn from_bytes<T>(bytes: T) -> Result<Digest, DigestParseError>
where T: AsRef<[u8]>,

Generates a digest from bytes.